@@ -26,23 +26,12 @@ def sorted(my_list):
 """
 
 TEST_SNIPPET = """\
-fruit = ['banana']
-try:
-    lunch = fruit[100]
-except (IndexError, TypeError):
-    print("No lunch for you!")
-except Exception as e:
-    print(f"Unknown error - details: {e}")
-
-try:
-    float('boat')
-except ValueError:
-    print("You can't float a boat! Only a number of some sort!")
-
-try:
-    names[100]
-except Exception:
-    print(names)
+n = -1
+for image in images:
+    if n % 10 == 0:
+        print(f"Just processed image {{n}}")
+    process_image(image)
+    n += 1
 """
 
 DEMO_SNIPPET = """\
