@@ -16,7 +16,7 @@ advisors.load_advisors()
 t = True
 f = False
 
-do_test = f  ## use test snippet rather than the larger demo snippet
+do_test = t  ## use test snippet rather than the larger demo snippet
 do_html = t  ## use html displayer vs cli displayer
 do_displayer = t  ## for dev testing only
 
